@@ -6,9 +6,9 @@ import (
 	"runtime"
 	"testing"
 
-	"gotest.tools/assert"
-	is "gotest.tools/assert/cmp"
-	"gotest.tools/skip"
+	"gotest.tools/v3/assert"
+	is "gotest.tools/v3/assert/cmp"
+	"gotest.tools/v3/skip"
 )
 
 func TestEqualMissingRoot(t *testing.T) {
@@ -270,5 +270,4 @@ t.go
 `, dir.Path())
 		assert.Equal(t, result.(cmpFailure).FailureMessage(), expected)
 	})
-
 }
